@@ -4,8 +4,8 @@
 
 ;; Author: Johannes Mueller <github@johannes-mueller.org>
 ;; URL: https://github.com/johannes-mueller/devcontainer.el
-;; Package-Version: 20260206.1809
-;; Package-Revision: 8e77740f17d2
+;; Package-Version: 20260213.2206
+;; Package-Revision: 37b915d2374d
 ;; License: GPLv3
 ;; SPDX-License-Identifier: GPL-3.0-only
 ;; Package-Requires: ((emacs "29.1"))
@@ -819,7 +819,11 @@ https://containers.dev/implementors/json_reference/#variables-in-devcontainerjso
     (with-temp-buffer
       (insert-file-contents (concat (file-name-as-directory (devcontainer--root)) devcontainer-json-file))
       (devcontainer--bust-json-comments-in-buffer)
-      (json-parse-string (buffer-string)))))
+      (condition-case nil
+          (json-parse-string (buffer-string))
+        (json-parse-error (progn
+                            (message "Broken json in devcontainer.json")
+                            nil))))))
 
 (defun devcontainer--determine-workspace-folder-from-container ()
   "Determine the remote workdir in the devcontainer."
